==> kadu_0.6.0.orig.tar.gz: mime_tex/translations/mime_tex_pl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>TeX formula support</source>
        <translation>Wsparcie dla formuł TeX-owych</translation>
    </message>
    <message>
        <source>Formula refreshment interval</source>
        <translation>Częstotliwość odświerzania obrazka</translation>
    </message>
    <message>
        <source>Default font size:</source>
        <translation>Domyślna wielkość czcionki:</translation>
    </message>
    <message>
        <source>Remove GIF files on module unload</source>
        <translation>Usuń Obrazki GIF przy wyładowaniu modułu</translation>
    </message>
    <message>
        <source>When this option is set, all formula images will be removed from
disk on module unload (e. g. when exiting Kadu). Note that only
files from the current MimeTeX session will be removed.</source>
        <translation>Gdy ta opcja jest zaznaczona, wszystkie obrazki zostaną usunięte
z dysku podczas syładowywania modułu (m. in. przy zakończeniu Kadu).
Usunięte zostaną obrazki wyłącznie z obecnej sesji MimeTeX.</translation>
    </message>
    <message>
        <source>Use transparent background</source>
        <translation>Używaj przezroczystego tła</translation>
    </message>
    <message>
        <source>mimetex binary is able to produce gif images with trasparent
background. It looks ok when the chat window&apos;s background is
in high contrast with the font color.</source>
        <translation>Program mimetex potrafi generować obrazki z przezroczystym
tłem. Wygląda to dobrze gdy kolor tła okna czata jest kontrastowe
w stosunku do koloru czcionki.</translation>
    </message>
</context>
<context>
    <name>MimeTeX</name>
    <message>
        <source>TeX formula</source>
        <translation>Obraz formuły</translation>
    </message>
</context>
<context>
    <name>TeXFormulaDialog</name>
    <message>
        <source>Formula image</source>
        <translation>Obraz formuły</translation>
    </message>
    <message>
        <source>Components</source>
        <translation>Komponenty</translation>
    </message>
    <message>
        <source>&amp;Relations</source>
        <translation>&amp;Relacje</translation>
    </message>
    <message>
        <source>&amp;Greek Letters</source>
        <translation>&amp;Greckie Litery</translation>
    </message>
    <message>
        <source>&amp;Arrows</source>
        <translation>&amp;Strzałki</translation>
    </message>
    <message>
        <source>&amp;Delimiters</source>
        <translation>&amp;Oddzielacze</translation>
    </message>
    <message>
        <source>&amp;Symbols</source>
        <translation>&amp;Symbole</translation>
    </message>
    <message>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
    <message>
        <source>TeX formula creator</source>
        <translation>Kreator formuł TeX-owych</translation>
    </message>
    <message>
        <source>Unable to run mimetex binary!</source>
        <translation>Nie mogę uruchomić programu mimetex!</translation>
    </message>
</context>
</TS>

==> kadu_0.6.5.1.orig.tar.gz: mime_tex/translations/mime_tex_pl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>TeX formula support</source>
        <translation>Wsparcie dla formuł TeX-owych</translation>
    </message>
    <message>
        <source>Formula refreshment interval</source>
        <translation>Częstotliwość odświeżania obrazka</translation>
    </message>
    <message>
        <source>Default font size:</source>
        <translation>Domyślna wielkość czcionki:</translation>
    </message>
    <message>
        <source>Remove GIF files on module unload</source>
        <translation>Usuń Obrazki GIF przy wyładowaniu modułu</translation>
    </message>
    <message>
        <source>When this option is set, all formula images will be removed from
disk on module unload (e. g. when exiting Kadu). Note that only
files from the current MimeTeX session will be removed.</source>
        <translation>Gdy ta opcja jest zaznaczona, wszystkie obrazki zostaną usunięte
z dysku podczas syładowywania modułu (m. in. przy zakończeniu Kadu).
Usunięte zostaną obrazki wyłącznie z obecnej sesji MimeTeX.</translation>
    </message>
    <message>
        <source>Use transparent background</source>
        <translation>Używaj przezroczystego tła</translation>
    </message>
    <message>
        <source>mimetex binary is able to produce gif images with trasparent
background. It looks ok when the chat window&apos;s background is
in high contrast with the font color.</source>
        <translation>Program mimetex potrafi generować obrazki z przezroczystym
tłem. Wygląda to dobrze gdy kolor tła okna czata jest kontrastowe
w stosunku do koloru czcionki.</translation>
    </message>
</context>
<context>
    <name>MimeTeX</name>
    <message>
        <source>TeX formula</source>
        <translation>Obraz formuły</translation>
    </message>
</context>
<context>
    <name>TeXFormulaDialog</name>
    <message>
        <source>Formula image</source>
        <translation>Obraz formuły</translation>
    </message>
    <message>
        <source>Components</source>
        <translation>Komponenty</translation>
    </message>
    <message>
        <source>&amp;Relations</source>
        <translation>&amp;Relacje</translation>
    </message>
    <message>
        <source>&amp;Greek Letters</source>
        <translation>&amp;Greckie Litery</translation>
    </message>
    <message>
        <source>&amp;Arrows</source>
        <translation>&amp;Strzałki</translation>
    </message>
    <message>
        <source>&amp;Delimiters</source>
        <translation>&amp;Oddzielacze</translation>
    </message>
    <message>
        <source>&amp;Symbols</source>
        <translation>&amp;Symbole</translation>
    </message>
    <message>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
    <message>
        <source>TeX formula creator</source>
        <translation>Kreator formuł TeX-owych</translation>
    </message>
    <message>
        <source>Unable to run mimetex binary!</source>
        <translation>Nie mogę uruchomić programu mimetex!</translation>
    </message>
</context>
</TS>
